pub struct Image {
pub buffer: Option<SerializedComponentBatch>,
pub format: Option<SerializedComponentBatch>,
pub opacity: Option<SerializedComponentBatch>,
pub draw_order: Option<SerializedComponentBatch>,
}Expand description
Archetype: A monochrome or color image.
See also archetypes::DepthImage and archetypes::SegmentationImage.
Rerun also supports compressed images (JPEG, PNG, …), using archetypes::EncodedImage.
For images that refer to video frames see archetypes::VideoFrameReference.
Compressing images or using video data instead can save a lot of bandwidth and memory.
The raw image data is stored as a single buffer of bytes in a components::Blob.
The meaning of these bytes is determined by the components::ImageFormat which specifies the resolution
and the pixel format (e.g. RGB, RGBA, …).
The order of dimensions in the underlying components::Blob follows the typical
row-major, interleaved-pixel image format.
Examples
image_simple:
use ndarray::{Array, ShapeBuilder as _, s};
fn main() -> Result<(), Box<dyn std::error::Error>> {
let rec = rerun::RecordingStreamBuilder::new("rerun_example_image").spawn()?;
let mut image = Array::<u8, _>::zeros((200, 300, 3).f());
image.slice_mut(s![.., .., 0]).fill(255);
image.slice_mut(s![50..150, 50..150, 0]).fill(0);
image.slice_mut(s![50..150, 50..150, 1]).fill(255);
rec.log(
"image",
&rerun::Image::from_color_model_and_tensor(rerun::ColorModel::RGB, image)?,
)?;
Ok(())
}
Logging images with various formats
use rerun::external::ndarray;
fn main() -> Result<(), Box<dyn std::error::Error>> {
let rec = rerun::RecordingStreamBuilder::new("rerun_example_image_formats").spawn()?;
// Simple gradient image
let image = ndarray::Array3::from_shape_fn((256, 256, 3), |(y, x, c)| match c {
0 => x as u8,
1 => (x + y).min(255) as u8,
2 => y as u8,
_ => unreachable!(),
});
// RGB image
rec.log(
"image_rgb",
&rerun::Image::from_color_model_and_tensor(rerun::ColorModel::RGB, image.clone())?,
)?;
// Green channel only (Luminance)
rec.log(
"image_green_only",
&rerun::Image::from_color_model_and_tensor(
rerun::ColorModel::L,
image.slice(ndarray::s![.., .., 1]).to_owned(),
)?,
)?;
// BGR image
rec.log(
"image_bgr",
&rerun::Image::from_color_model_and_tensor(
rerun::ColorModel::BGR,
image.slice(ndarray::s![.., .., ..;-1]).to_owned(),
)?,
)?;
// New image with Separate Y/U/V planes with 4:2:2 chroma downsampling
let mut yuv_bytes = Vec::with_capacity(256 * 256 + 128 * 256 * 2);
yuv_bytes.extend(std::iter::repeat_n(128, 256 * 256)); // Fixed value for Y.
yuv_bytes.extend((0..256).flat_map(|_y| (0..128).map(|x| x * 2))); // Gradient for U.
yuv_bytes.extend((0..256).flat_map(|y| std::iter::repeat_n(y as u8, 128))); // Gradient for V.
rec.log(
"image_yuv422",
&rerun::Image::from_pixel_format(
[256, 256],
rerun::PixelFormat::Y_U_V16_FullRange,
yuv_bytes,
),
)?;
Ok(())
}
Fields
buffer: Option<SerializedComponentBatch>The raw image data.
format: Option<SerializedComponentBatch>The format of the image.
opacity: Option<SerializedComponentBatch>Opacity of the image, useful for layering several media.
Defaults to 1.0 (fully opaque).
draw_order: Option<SerializedComponentBatch>An optional floating point value that specifies the 2D drawing order.
Objects with higher values are drawn on top of those with lower values.
Defaults to -10.0.
Implementations
Sourceimpl Image
impl Image
Sourcepub fn descriptor_buffer() -> ComponentDescriptor
pub fn descriptor_buffer() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::buffer.
The corresponding component is crate::components::ImageBuffer.
Sourcepub fn descriptor_format() -> ComponentDescriptor
pub fn descriptor_format() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::format.
The corresponding component is crate::components::ImageFormat.
Sourcepub fn descriptor_opacity() -> ComponentDescriptor
pub fn descriptor_opacity() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::opacity.
The corresponding component is crate::components::Opacity.
Sourcepub fn descriptor_draw_order() -> ComponentDescriptor
pub fn descriptor_draw_order() -> ComponentDescriptor
Returns the ComponentDescriptor for Self::draw_order.
The corresponding component is crate::components::DrawOrder.
Sourceimpl Image
impl Image
Sourcepub const NUM_COMPONENTS: usize = 4usize
pub const NUM_COMPONENTS: usize = 4usize
The total number of components in the archetype: 2 required, 0 recommended, 2 optional
Sourceimpl Image
impl Image
Sourcepub fn new(
buffer: impl Into<ImageBuffer>,
format: impl Into<ImageFormat>,
) -> Self
pub fn new( buffer: impl Into<ImageBuffer>, format: impl Into<ImageFormat>, ) -> Self
Create a new Image.
Sourcepub fn update_fields() -> Self
pub fn update_fields() -> Self
Update only some specific fields of a Image.
Sourcepub fn clear_fields() -> Self
pub fn clear_fields() -> Self
Clear all the fields of a Image.
Sourcepub fn columns<I>(
self,
_lengths: I,
) -> SerializationResult<impl Iterator<Item = SerializedComponentColumn>>
pub fn columns<I>( self, _lengths: I, ) -> SerializationResult<impl Iterator<Item = SerializedComponentColumn>>
Partitions the component data into multiple sub-batches.
Specifically, this transforms the existing SerializedComponentBatches data into SerializedComponentColumns
instead, via SerializedComponentBatch::partitioned.
This makes it possible to use RecordingStream::send_columns to send columnar data directly into Rerun.
The specified lengths must sum to the total length of the component batch.
Sourcepub fn columns_of_unit_batches(
self,
) -> SerializationResult<impl Iterator<Item = SerializedComponentColumn>>
pub fn columns_of_unit_batches( self, ) -> SerializationResult<impl Iterator<Item = SerializedComponentColumn>>
Helper to partition the component data into unit-length sub-batches.
This is semantically similar to calling Self::columns with std::iter::take(1).repeat(n),
where n is automatically guessed.
Sourcepub fn with_buffer(self, buffer: impl Into<ImageBuffer>) -> Self
pub fn with_buffer(self, buffer: impl Into<ImageBuffer>) -> Self
The raw image data.
Sourcepub fn with_many_buffer(
self,
buffer: impl IntoIterator<Item = impl Into<ImageBuffer>>,
) -> Self
pub fn with_many_buffer( self, buffer: impl IntoIterator<Item = impl Into<ImageBuffer>>, ) -> Self
This method makes it possible to pack multiple crate::components::ImageBuffer in a single component batch.
This only makes sense when used in conjunction with Self::columns. Self::with_buffer should
be used when logging a single row’s worth of data.
Sourcepub fn with_format(self, format: impl Into<ImageFormat>) -> Self
pub fn with_format(self, format: impl Into<ImageFormat>) -> Self
The format of the image.
Sourcepub fn with_many_format(
self,
format: impl IntoIterator<Item = impl Into<ImageFormat>>,
) -> Self
pub fn with_many_format( self, format: impl IntoIterator<Item = impl Into<ImageFormat>>, ) -> Self
This method makes it possible to pack multiple crate::components::ImageFormat in a single component batch.
This only makes sense when used in conjunction with Self::columns. Self::with_format should
be used when logging a single row’s worth of data.
Sourcepub fn with_opacity(self, opacity: impl Into<Opacity>) -> Self
pub fn with_opacity(self, opacity: impl Into<Opacity>) -> Self
Opacity of the image, useful for layering several media.
Defaults to 1.0 (fully opaque).
Sourcepub fn with_many_opacity(
self,
opacity: impl IntoIterator<Item = impl Into<Opacity>>,
) -> Self
pub fn with_many_opacity( self, opacity: impl IntoIterator<Item = impl Into<Opacity>>, ) -> Self
This method makes it possible to pack multiple crate::components::Opacity in a single component batch.
This only makes sense when used in conjunction with Self::columns. Self::with_opacity should
be used when logging a single row’s worth of data.
Sourcepub fn with_draw_order(self, draw_order: impl Into<DrawOrder>) -> Self
pub fn with_draw_order(self, draw_order: impl Into<DrawOrder>) -> Self
An optional floating point value that specifies the 2D drawing order.
Objects with higher values are drawn on top of those with lower values.
Defaults to -10.0.
Sourcepub fn with_many_draw_order(
self,
draw_order: impl IntoIterator<Item = impl Into<DrawOrder>>,
) -> Self
pub fn with_many_draw_order( self, draw_order: impl IntoIterator<Item = impl Into<DrawOrder>>, ) -> Self
This method makes it possible to pack multiple crate::components::DrawOrder in a single component batch.
This only makes sense when used in conjunction with Self::columns. Self::with_draw_order should
be used when logging a single row’s worth of data.
Sourceimpl Image
impl Image
Sourcepub fn from_color_model_and_tensor<T>(
color_model: ColorModel,
data: T,
) -> Result<Self, ImageConstructionError<T>>
pub fn from_color_model_and_tensor<T>( color_model: ColorModel, data: T, ) -> Result<Self, ImageConstructionError<T>>
Try to construct an Image from a color model (L, RGB, RGBA, …) and anything that can be converted into TensorData.
Will return an ImageConstructionError if the shape of the tensor data does not match the given color model.
This is useful for constructing an Image from an ndarray.
See also Self::from_pixel_format.
Sourcepub fn from_pixel_format(
[width, height]: [u32; 2],
pixel_format: PixelFormat,
bytes: impl Into<ImageBuffer>,
) -> Self
pub fn from_pixel_format( [width, height]: [u32; 2], pixel_format: PixelFormat, bytes: impl Into<ImageBuffer>, ) -> Self
Construct an image from a byte buffer given its resolution and pixel format.
See also Self::from_color_model_and_tensor.
Sourcepub fn from_color_model_and_bytes(
bytes: impl Into<ImageBuffer>,
[width, height]: [u32; 2],
color_model: ColorModel,
datatype: ChannelDatatype,
) -> Self
pub fn from_color_model_and_bytes( bytes: impl Into<ImageBuffer>, [width, height]: [u32; 2], color_model: ColorModel, datatype: ChannelDatatype, ) -> Self
Construct an image from a byte buffer given its resolution, color model, and data type.
See also Self::from_color_model_and_tensor.
Sourcepub fn from_elements<T: ImageChannelType>(
elements: &[T],
[width, height]: [u32; 2],
color_model: ColorModel,
) -> Self
pub fn from_elements<T: ImageChannelType>( elements: &[T], [width, height]: [u32; 2], color_model: ColorModel, ) -> Self
Construct an image from a byte buffer given its resolution, color model, and using the data type of the given vector.
Sourcepub fn from_l8(bytes: impl Into<ImageBuffer>, resolution: [u32; 2]) -> Self
pub fn from_l8(bytes: impl Into<ImageBuffer>, resolution: [u32; 2]) -> Self
From an 8-bit grayscale image.
Sourcepub fn from_rgb24(bytes: impl Into<ImageBuffer>, resolution: [u32; 2]) -> Self
pub fn from_rgb24(bytes: impl Into<ImageBuffer>, resolution: [u32; 2]) -> Self
Assumes RGB, 8-bit per channel, interleaved as RGBRGBRGB.
Sourcepub fn from_rgba32(bytes: impl Into<ImageBuffer>, resolution: [u32; 2]) -> Self
pub fn from_rgba32(bytes: impl Into<ImageBuffer>, resolution: [u32; 2]) -> Self
Assumes RGBA, 8-bit per channel, with separate alpha.
Sourcepub fn from_file_path(filepath: impl AsRef<Path>) -> Result<EncodedImage>
👎Deprecated: Use EncodedImage::from_file instead
pub fn from_file_path(filepath: impl AsRef<Path>) -> Result<EncodedImage>
Creates a new Image from a file.
The image format will be inferred from the path (extension), or the contents if that fails.
Sourcepub fn from_file_contents(
contents: Vec<u8>,
_format: Option<ImageFormat>,
) -> EncodedImage
👎Deprecated: Use EncodedImage::from_file_contents instead
pub fn from_file_contents( contents: Vec<u8>, _format: Option<ImageFormat>, ) -> EncodedImage
Creates a new Image from the contents of a file.
If unspecified, the image format will be inferred from the contents.
Sourceimpl Image
impl Image
Sourcepub fn from_image_bytes(
format: ImageFormat,
file_contents: &[u8],
) -> Result<Self, ImageLoadError>
pub fn from_image_bytes( format: ImageFormat, file_contents: &[u8], ) -> Result<Self, ImageLoadError>
Construct an image from the contents of an image file.
This will spend CPU cycles decoding the image.
To save CPU time and storage, we recommend you instead use
EncodedImage::from_file_contents.
Requires the image feature.
Sourcepub fn from_image(
image: impl Into<DynamicImage>,
) -> Result<Self, ImageConversionError>
pub fn from_image( image: impl Into<DynamicImage>, ) -> Result<Self, ImageConversionError>
Construct an image from something that can be turned into a image::DynamicImage.
Requires the image feature.
Sourcepub fn from_dynamic_image(
image: DynamicImage,
) -> Result<Self, ImageConversionError>
pub fn from_dynamic_image( image: DynamicImage, ) -> Result<Self, ImageConversionError>
Construct an image from image::DynamicImage.
Requires the image feature.