#[repr(transparent)]pub struct ClassId(pub ClassId);Expand description
Component: A 16-bit ID representing a type of semantic class.
Used to look up a crate::datatypes::ClassDescription within the crate::components::AnnotationContext.
Tuple Fields
0: ClassIdTrait Implementations
Sourceimpl Component for ClassId
impl Component for ClassId
Sourcefn name() -> ComponentType
fn name() -> ComponentType
The fully-qualified type of this component, e.g.
rerun.components.Position2D.Sourceimpl<'de> Deserialize<'de> for ClassId
impl<'de> Deserialize<'de> for ClassId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Loggable for ClassId
impl Loggable for ClassId
Sourcefn arrow_datatype() -> DataType
fn arrow_datatype() -> DataType
The underlying
arrow::datatypes::DataType, excluding datatype extensions.Sourcefn to_arrow_opt<'a>(
data: impl IntoIterator<Item = Option<impl Into<Cow<'a, Self>>>>,
) -> SerializationResult<ArrayRef>where
Self: Clone + 'a,
fn to_arrow_opt<'a>(
data: impl IntoIterator<Item = Option<impl Into<Cow<'a, Self>>>>,
) -> SerializationResult<ArrayRef>where
Self: Clone + 'a,
Sourcefn from_arrow_opt(
arrow_data: &dyn Array,
) -> DeserializationResult<Vec<Option<Self>>>where
Self: Sized,
fn from_arrow_opt(
arrow_data: &dyn Array,
) -> DeserializationResult<Vec<Option<Self>>>where
Self: Sized,
Given an Arrow array, deserializes it into a collection of optional
Loggables.Sourcefn from_arrow(arrow_data: &dyn Array) -> DeserializationResult<Vec<Self>>where
Self: Sized,
fn from_arrow(arrow_data: &dyn Array) -> DeserializationResult<Vec<Self>>where
Self: Sized,
Given an Arrow array, deserializes it into a collection of
Loggables.fn arrow_empty() -> Arc<dyn Array>
Sourcefn to_arrow<'a>(
data: impl IntoIterator<Item = impl Into<Cow<'a, Self>>>,
) -> Result<Arc<dyn Array>, SerializationError>where
Self: 'a,
fn to_arrow<'a>(
data: impl IntoIterator<Item = impl Into<Cow<'a, Self>>>,
) -> Result<Arc<dyn Array>, SerializationError>where
Self: 'a,
Sourcefn verify_arrow_array(data: &dyn Array) -> Result<(), DeserializationError>
fn verify_arrow_array(data: &dyn Array) -> Result<(), DeserializationError>
Sourceimpl Ord for ClassId
impl Ord for ClassId
Sourceimpl PartialOrd for ClassId
impl PartialOrd for ClassId
Sourceimpl SizeBytes for ClassId
impl SizeBytes for ClassId
Sourcefn heap_size_bytes(&self) -> u64
fn heap_size_bytes(&self) -> u64
Returns how many bytes
self uses on the heap. Read moreSourcefn total_size_bytes(&self) -> u64
fn total_size_bytes(&self) -> u64
Returns the total size of
self in bytes, accounting for both stack and heap space.Sourcefn stack_size_bytes(&self) -> u64
fn stack_size_bytes(&self) -> u64
Returns the total size of
self on the stack, in bytes. Read moreimpl Copy for ClassId
impl Eq for ClassId
impl Pod for ClassId
impl StructuralPartialEq for ClassId