pub enum ImageConversionError {
UnsupportedImageColorType(ColorType),
}Expand description
Errors when converting images from the image crate to an archetypes::Image.
Variants
UnsupportedImageColorType(ColorType)
Unknown color type from the image crate.
This should only happen if you are using a newer image crate than the one Rerun was built for,
because image can add new color types without it being a breaking change,
so we cannot exhaustively match on all color types.